==> leancrypto-1.5.1.tar.xz: leancrypto-1.5.1/asn1/src/asymmetric_type.h <==
/*
 * Copyright (C) 2024 - 2025, Stephan Mueller <smueller@chronox.de>
 *
 * License: see LICENSE file in root directory
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, ALL OF
 * WHICH ARE HEREBY DISCLAIMED.  NO EVENT SHALL THE AUTHOR BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING ANY WAY OF THE
 * USE OF THIS SOFTWARE, EVEN IF NOT ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
/*
 * This code is derived in parts from the Linux kernel
 * License: SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2012 Red Hat, Inc. All Rights Reserved.
 * Written by David Howells (dhowells@redhat.com)
 */

#ifndef ASYMMETRIC_TYPE_H
#define ASYMMETRIC_TYPE_H

#include "ext_headers.h"
#include "lc_x509_parser.h"

#ifdef __cplusplus
extern "C" {
#endif

extern int asymmetric_key_id_same(const struct lc_asymmetric_key_id *kid1,
				  const struct lc_asymmetric_key_id *kid2);

extern int asymmetric_key_generate_id(struct lc_asymmetric_key_id *,
				      const uint8_t *val_1, size_t len_1,
				      const uint8_t *val_2, size_t len_2);

/*
 * The payload is at the discretion of the subtype.
 */

#ifdef __cplusplus
}
#endif

#endif /* ASYMMETRIC_TYPE_H */

==> leancrypto-1.6.0.tar.xz: leancrypto-1.6.0/asn1/src/asymmetric_type.h <==
/*
 * Copyright (C) 2024 - 2025, Stephan Mueller <smueller@chronox.de>
 *
 * License: see LICENSE file in root directory
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, ALL OF
 * WHICH ARE HEREBY DISCLAIMED.  NO EVENT SHALL THE AUTHOR BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING ANY WAY OF THE
 * USE OF THIS SOFTWARE, EVEN IF NOT ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
/*
 * This code is derived in parts from the Linux kernel
 * License: SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2012 Red Hat, Inc. All Rights Reserved.
 * Written by David Howells (dhowells@redhat.com)
 */
/*
 * Red Hat granted the following additional license to the leancrypto project:
 * SPDX-License-Identifier: BSD-3-Clause
 */

#ifndef ASYMMETRIC_TYPE_H
#define ASYMMETRIC_TYPE_H

#include "ext_headers_internal.h"
#include "lc_x509_parser.h"

#ifdef __cplusplus
extern "C" {
#endif

extern int asymmetric_key_id_same(const struct lc_asymmetric_key_id *kid1,
				  const struct lc_asymmetric_key_id *kid2);

extern int asymmetric_key_generate_id(struct lc_asymmetric_key_id *,
				      const uint8_t *val_1, size_t len_1,
				      const uint8_t *val_2, size_t len_2);

/*
 * The payload is at the discretion of the subtype.
 */

#ifdef __cplusplus
}
#endif

#endif /* ASYMMETRIC_TYPE_H */
